# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext as _
from image_cropping import ImageCroppingMixin

from . import models


class CategoryAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': ('name', 'slug',)
        }),
        (_('visualization admin'), {
            'fields': ('status', 'ordering'),
        }),
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create',
                'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'get_status_display', 'name', 'slug',
    )
    readonly_fields = (
        'creator', 'date_create', 'last_modifier', 'date_last_modify',
    )
    prepopulated_fields = {'slug': ('name',)}


class NewsAdmin(ImageCroppingMixin, admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': (
                'categories', 'title',
                'slug', 'language', 'event_date', 'link',
                'short_description', 'full_description', 'note')
        }),
        (_('visualization admin'), {
            'fields': (
                'status', 'ordering',
                'pub_date_begin', 'pub_date_end'),
        }),
        (_('file admin'), {
            'fields': (
                'small_image', 'big_image',
                'small_cropping', 'big_cropping', 'file'),
        }),
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create',
                'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'get_status_display', 'title', 'slug', 'language', 'event_date'
    )
    readonly_fields = (
        'creator', 'date_create', 'last_modifier', 'date_last_modify',
    )
    prepopulated_fields = {'slug': ('title',)}


admin.site.register(models.Category, CategoryAdmin)
admin.site.register(models.News, NewsAdmin)
