# -*- coding: utf-8 -*-

from rest_framework import generics

from thux.api.views import QuerysetMixin
from thux.api.permissions import ThuxModelPermissions

from .. import models
from . import serializers


class CategoryList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Category.objects.all()
    serializer_class = serializers.CategorySerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(CategoryList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class CategoryRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Category.objects.all()
    serializer_class = serializers.CategorySerializer


class CategoryCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Category.objects.all()
    serializer_class = serializers.CategorySerializerCreate


class CategoryUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Category.objects.all()
    serializer_class = serializers.CategorySerializerUpdate


class NewsList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.News.objects.all()
    serializer_class = serializers.NewsSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(NewsList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class NewsRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.News.objects.all()
    serializer_class = serializers.NewsSerializer


class NewsCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.News.objects.all()
    serializer_class = serializers.NewsSerializerCreate


class NewsItemUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.News.objects.all()
    serializer_class = serializers.NewsSerializerUpdate
