# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
from django.conf import settings
import ckeditor.fields
import thux.news.models
import image_cropping.fields


class Migration(migrations.Migration):

    dependencies = [
        ('i18n', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(verbose_name='date create', null=True, blank=True)),
                ('date_last_modify', models.DateTimeField(verbose_name='date last modify', null=True, blank=True)),
                ('status', models.IntegerField(choices=[(0, 'Inactive'), (1, 'Active')], verbose_name='Status', null=True, default=1)),
                ('ordering', models.IntegerField(verbose_name='ordering', default=0)),
                ('name', models.CharField(max_length=255, unique=True, verbose_name='name')),
                ('slug', models.SlugField(max_length=255, unique=True, verbose_name='slug')),
                ('creator', models.ForeignKey(to=settings.AUTH_USER_MODEL, related_name='news_category_creator', null=True, verbose_name='creator', blank=True)),
                ('last_modifier', models.ForeignKey(to=settings.AUTH_USER_MODEL, related_name='news_category_last_modifier', null=True, verbose_name='last modifier', blank=True)),
            ],
            options={
                'verbose_name_plural': 'categories',
                'verbose_name': 'category',
                'ordering': ('ordering', 'name'),
                'permissions': (('list_category', 'Can list category'), ('detail_category', 'Can detail category'), ('disable_category', 'Can disable category')),
            },
        ),
        migrations.CreateModel(
            name='News',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(verbose_name='date create', null=True, blank=True)),
                ('date_last_modify', models.DateTimeField(verbose_name='date last modify', null=True, blank=True)),
                ('status', models.IntegerField(choices=[(0, 'Inactive'), (1, 'Active')], verbose_name='Status', null=True, default=1)),
                ('ordering', models.IntegerField(verbose_name='ordering', default=0)),
                ('meta_description', models.TextField(max_length=255, blank=True, verbose_name='description')),
                ('meta_keywords', models.CharField(max_length=255, blank=True, verbose_name='keywords')),
                ('page_title', models.CharField(max_length=255, blank=True, help_text='overwrite the title (html title tag)', verbose_name='title')),
                ('title', models.CharField(max_length=255, unique=True, verbose_name='default title')),
                ('slug', models.SlugField(max_length=255, unique=True, verbose_name='slug')),
                ('event_date', models.DateField(verbose_name='news date', null=True, blank=True)),
                ('pub_date_begin', models.DateTimeField(verbose_name='publication date begin', null=True, blank=True)),
                ('pub_date_end', models.DateTimeField(verbose_name='publication date end', null=True, blank=True)),
                ('small_image', models.ImageField(null=True, blank=True, upload_to=thux.news.models.get_upload_small_path, verbose_name='small Image')),
                ('big_image', models.ImageField(null=True, blank=True, upload_to=thux.news.models.get_upload_big_path, verbose_name='Big Image')),
                ('small_cropping', image_cropping.fields.ImageRatioField('big_image', '430x360', free_crop=False, hide_image_field=False, help_text=None, adapt_rotation=False, allow_fullsize=False, verbose_name='small cropping', size_warning=True)),
                ('big_cropping', image_cropping.fields.ImageRatioField('big_image', '1200x628', free_crop=False, hide_image_field=False, help_text=None, adapt_rotation=False, allow_fullsize=False, verbose_name='big cropping', size_warning=True)),
                ('short_description', models.CharField(max_length=255, null=True, blank=True, verbose_name='short description')),
                ('full_description', ckeditor.fields.RichTextField(verbose_name='full description', null=True, blank=True)),
                ('note', models.TextField(verbose_name='note', null=True, blank=True)),
                ('file', models.FileField(null=True, blank=True, upload_to=thux.news.models.get_upload_file_path, verbose_name='file')),
                ('link', models.URLField(null=True, blank=True, verbose_name='link')),
                ('categories', models.ManyToManyField(to='news.Category', verbose_name='categories', related_name='news', blank=True)),
                ('creator', models.ForeignKey(to=settings.AUTH_USER_MODEL, related_name='news_news_creator', null=True, verbose_name='creator', blank=True)),
                ('language', models.ForeignKey(to='i18n.Language', null=True, verbose_name='language', blank=True)),
                ('last_modifier', models.ForeignKey(to=settings.AUTH_USER_MODEL, related_name='news_news_last_modifier', null=True, verbose_name='last modifier', blank=True)),
            ],
            options={
                'verbose_name_plural': 'news',
                'verbose_name': 'news',
                'ordering': ('ordering', '-event_date', 'title'),
                'permissions': (('list_news', 'Can list news'), ('detail_news', 'Can detail news'), ('disable_news', 'Can disable news')),
            },
        ),
    ]
